View source: R/calculate_rolling_timedummy.R
| calculate_rolling_timedummy | R Documentation |
Estimates a price index using rolling windows of time dummy regressions.
calculate_rolling_timedummy(
dataset,
period_variable,
dependent_variable,
numerical_variables,
categorical_variables,
reference_period,
window_length,
number_of_observations = FALSE
)
dataset |
data frame with input data |
period_variable |
name of the time variable (string) |
dependent_variable |
name of the dependent variable (usually price, assumed unlogged) |
numerical_variables |
vector of numeric quality-determining variables |
categorical_variables |
vector of categorical variables |
reference_period |
period to be normalized to index = 100 (e.g., "2015") |
window_length |
length of each rolling window (integer) |
number_of_observations |
logical, whether to return number of observations per period (default = FALSE) |
data frame with period, Index, and optionally number_of_observations
Vivek Gajadhar
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.