smooth_ts: Run forward and backward pass of time series estimation

View source: R/ts_helpers.R

smooth_tsR Documentation

Run forward and backward pass of time series estimation

Description

Calculate a trend line based on a provided model. This function is used in the function: calculate_trend_line_KFAS()

Usage

smooth_ts(fittedmodel)

Arguments

fittedmodel

model values as output of the function estimate.TS.parameters()

Value

A list containing multiple elements; sub-list signalsubconf[, 1] provides the estimated trend line.

Author(s)

Pim Ouwehand, Farley Ishaak


REPS documentation built on March 16, 2026, 5:08 p.m.