View source: R/calculate_hedonic_index.R
| calculate_hedonic_index | R Documentation |
Central hub function to calculate index figures using different methods.
calculate_hedonic_index(
dataset,
method,
period_variable,
dependent_variable,
numerical_variables = NULL,
categorical_variables = NULL,
reference_period = NULL,
number_of_observations = TRUE,
...
)
dataset |
Data frame with input data |
method |
One of: "fisher", "laspeyres", "paasche", "hmts", "timedummy", "rolling_timedummy", "repricing" |
period_variable |
A string with the name of the column containing time periods. |
dependent_variable |
Usually the price |
numerical_variables |
Vector with numeric quality-determining variables |
categorical_variables |
Vector with categorical variables (also dummies) |
reference_period |
Period or group of periods that will be set to 100 |
number_of_observations |
Logical, whether to show number of observations (default = TRUE) |
... |
Additional method-specific arguments passed to the underlying functions:
|
A data.frame (or list for HMTS with resting_points = TRUE; or named list if multiple methods are used)
Vivek Gajadhar
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.