View source: R/calculate_hedonic_index.R
| plot_price_index | R Documentation |
Static price index plot using base R graphics with grid lines and external legend.
plot_price_index(index_output, title = NULL)
index_output |
A data.frame or named list of data.frames (from calculate_hedonic_index()) |
title |
Optional plot title |
Supports both single index data.frame and named list of multiple methods. X-axis shows only first period of each year with rotated labels to avoid clutter.
None. Draws plots in the active graphics device.
Vivek Gajadhar
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.